import { Command } from 'commander';
import CliCommand from './cli-command';
export default class Signer extends CliCommand {
    constructorJson: any;
    constructor();
    options(module: Command): void;
    handler(module: Command): void;
    checkJavaInstallation(): boolean;
    /**
     * Helper method that initializes the global connector.json file based on the CWD and checks
     * for a valid connector structure.
     *
     * @returns True if the connectorJson was parsed successfully
     */
    loadConnectorJson(): boolean;
    /**
     * Creates a signing resources folder in the connector folder that contains a newly
     * created keypair/keystore, a self-signed certificate, and a certificate signing
     * request that can be sent to a trusted CA for signing.
     *
     * @param userInput Input parameter only used for testing purposes that passes input in keypair creation.
     * @returns True if the CSR is generated successfully.
     */
    genCsr(userInput?: string[] | null): boolean;
    /**
     * Prompts the user for their keystore password, their signature alias and what they
     * want their signed TACO to be named, and then signs their .taco file while also
     * prompting the user to see if they want to delete the original.
     *
     * @param keystorePath
     */
    signTacoFile(keystorePath: string, userInput?: string[] | null): boolean;
    /**
     * Prompts user to enter the keystore password, taco alias, and new name for the .taco file.
     *
     * @returns Returns string array containing password, alias, and name
     */
    getUserInfo(): string[];
    /**
     * Helper method that prompts and asks user if they want to delete the unsigned .taco file.
     *
     * @param userInput User input used only for testing purposes that decides whether or not to delete the unsigned taco.
     */
    deleteUnsignedTacoPrompt(userInput?: string | null): void;
    importSignedCert(certPath: string, keystorePath: string, password: string): void;
}
