/// <reference types="node" />
import { ChildProcess } from 'child_process';
/** Cache of resources and settings used for connections keyed by connection id. */
declare class ConnectionResourceMgr {
    /** Resources by connectionId */
    private resourceMap;
    private getOrAddResources;
    setBrowserProcess(connectionId: string, procOrCloseFunc: ChildProcess | (() => void)): void;
    addExtractorProcess(connectionId: string, proc: ChildProcess, extractorId?: string): void;
    getExtractorCount(connectionId: string): number;
    hasConnector(connectionId: string): boolean;
    /** Frees all resources allocated for this connection. */
    free(connectionId: string): void;
    /** Frees browser resources (process) allocated for this connection. */
    freeBrowser(connectionId: string): void;
    /**
     * @param extractorIds Kills and deregister the specified extractor processses. If omitted, it will remove all extractors.
     * @returns Array of the extractor IDs that are terminated.
     */
    freeExtractors(connectionId: string, extractorIds?: string[]): string[];
    /** Gets if the connection has been submitted, that is, the interactive phase has completed with submit. */
    isSubmitted(connectionId: string): boolean;
    /** Sets if the connection has been submitted, that is, the interactive phase has completed with submit. */
    setIsSubmitted(connectorId: string, isSubmitted: boolean): void;
    /** Gets the distinct, unique connector name used by this connection id. */
    distinctConnectorName(connectionId: string): string | null;
    /** Sets the distinct, unique connector name used by this connection id. */
    setDistinctConnectorName(connectionId: string, distinctConnectorName: string): void;
    get size(): number;
}
/** Cache of resources and settings used for connections, keyed by connection id. */
declare const connectionResourceMgr: ConnectionResourceMgr;
export default connectionResourceMgr;
